Index: /trunk/src/VBox/Frontends/VirtualBox/src/runtime/UIMachineWindow.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/runtime/UIMachineWindow.h	(revision 50806)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/runtime/UIMachineWindow.h	(revision 50807)
@@ -74,4 +74,7 @@
 
 protected slots:
+
+    /** Sets the top-level widget containing this widget to be the active window. */
+    void sltActivateWindow() { activateWindow(); }
 
     /* Session event-handlers: */
Index: /trunk/src/VBox/Frontends/VirtualBox/src/runtime/UIMouseHandler.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/runtime/UIMouseHandler.cpp	(revision 50806)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/runtime/UIMouseHandler.cpp	(revision 50807)
@@ -22,4 +22,5 @@
 #include <QMouseEvent>
 #include <QTouchEvent>
+#include <QTimer>
 
 /* GUI includes: */
@@ -597,6 +598,6 @@
                         QApplication::activeWindow() != pWatchedWidget->window())
                     {
-                        /* Activating hovered machine window: */
-                        pWatchedWidget->window()->activateWindow();
+                        /* Activating hovered machine-window in 300msec: */
+                        QTimer::singleShot(300, pWatchedWidget->window(), SLOT(sltActivateWindow()));
 #ifdef Q_WS_X11
                         /* On X11 its not enough to just activate window if you
